@@ -19,15 +19,23 @@ use Class::Accessor::Lite (
 use base qw/Exporter/;
 
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 our @EXPORT = qw/new root_dir psgi build_app _router _connect get post router filter _wrap_filter/;
 
 sub new {
     my $class = shift;
-    my $root_dir = shift;
-    my @caller = caller;
-    $root_dir ||= File::Basename::dirname( Cwd::realpath($caller[1]) );
-    bless { root_dir => $root_dir }, $class;
+    my %args;
+    if ( @_ < 2 ) {
+        my $root_dir = shift;
+        my @caller = caller;
+        $root_dir ||= File::Basename::dirname( Cwd::realpath($caller[1]) );
+        $args{root_dir} = $root_dir;
+    }
+    else {
+        %args = @_;
+    }
+
+    bless \%args, $class;
 }
 
 sub psgi {
@@ -515,7 +523,7 @@ Kossy exports some methods to building application
 
 =over 4
 
-=item my $kossy = Kossy->new($root_dir);
+=item my $kossy = Kossy->new( root_dir => $root_dir );
 
 Create instance of the application object.
 
